@@ -6,7 +6,6 @@ use Carmel;
 use Carp ();
 use Carmel::Repository;
 use Config qw(%Config);
-use CPAN::Meta;
 use CPAN::Meta::Requirements;
 use File::Temp;
 use File::Basename;
@@ -41,6 +40,11 @@ sub repository_path {
     $ENV{PERL_CARMEL_REPO} || "$ENV{HOME}/.perl-carmel/builds/$self->{perl_arch}";
 }
 
+sub repo {
+    my $self = shift;
+    $self->{repo} ||= $self->build_repo;
+}
+
 sub build_repo {
     my $self = shift;
     my $repo = Carmel::Repository->new;
@@ -56,6 +60,17 @@ sub cmd_install {
     } else {
         $self->install("--installdeps", ".");
     }
+
+    my @artifacts;
+    $self->resolve(sub {
+        my($artifact, $depth) = @_;
+        if ($depth == 0) {
+            printf "Using %s (%s)\n", $artifact->package, $artifact->version || '0';
+        }
+        push @artifacts, $artifact;
+    });
+
+    print "---> Complete! @{[scalar @artifacts]} artifacts resolved and installed.\n";
 }
 
 sub is_core {
@@ -105,7 +120,7 @@ sub cmd_exec {
 sub cmd_find {
     my($self, $module, $requirement) = @_;
 
-    my @artifacts = $self->build_repo->find_all($module, $requirement || '0');
+    my @artifacts = $self->repo->find_all($module, $requirement || '0');
     for my $artifact (@artifacts) {
         printf "%s (%s) in %s\n", $artifact->package, $artifact->version || '0', $artifact->path;
     }
@@ -181,6 +196,10 @@ sub pad {
 
 sub try_snapshot {
     my $self = shift;
+
+    # TODO loading snapshot without install causes artifacts not found
+    return;
+
     if (my $cpanfile = $self->try_cpanfile) {
         return "$cpanfile.snapshot" if -e "$cpanfile.snapshot";
     }
@@ -233,24 +252,22 @@ sub snapshot_to_requirements {
 sub resolve_recursive {
     my($self, $root_reqs, $requirements, $seen, $cb, $depth) = @_;
 
-    my $repo = $self->build_repo;
-
     for my $module (sort $requirements->required_modules) {
         next if $module eq 'perl';
 
         my $want_version = $requirements->requirements_for_module($module);
-        if ($self->is_core($module, $want_version)) {
-            next;
-        } elsif (my $artifact = $repo->find($module, $want_version)) {
-            next if $seen->{$artifact->path}++;
-            $cb->($artifact, $depth);
-            my $meta = CPAN::Meta->load_file($artifact->path . "/MYMETA.json");
-            my $reqs = $meta->effective_prereqs->merged_requirements(['runtime'], ['requires']);
-            $root_reqs->add_requirements($reqs);
-            $self->resolve_recursive($root_reqs, $reqs, $seen, $cb, $depth + 1);
-        } else {
-            die "Coulld not find an artifact for $module => $want_version\n";
-        }
+        next if $self->is_core($module, $want_version);
+
+        my $artifact = $self->repo->find($module, $want_version)
+          or die "Could not find an artifact for $module => $want_version\nYou need to run `carmel install` first to get the modules installed and artifacts built.\n";
+
+        next if $seen->{$artifact->path}++;
+        $cb->($artifact, $depth);
+
+        my $reqs = $artifact->requirements;
+        $root_reqs->add_requirements($reqs);
+
+        $self->resolve_recursive($root_reqs, $reqs, $seen, $cb, $depth + 1);
     }
 }
 
@@ -259,11 +276,7 @@ sub resolve {
 
     my $requirements = $self->build_requirements
       or Carp::croak "Could not locate 'cpanfile' to load module list.";
-
-    my @artifacts;
     $self->resolve_recursive($requirements, $requirements, {}, $cb, 0);
-
-    @artifacts;
 }
 
 sub env {
