@@ -1,5 +1,6 @@
 package Carmel::Artifact;
 use strict;
+use CPAN::Meta;
 
 sub new {
     my($class, @args) = @_;
@@ -29,4 +30,14 @@ sub libs {
     ($self->blib . "/arch", $self->blib . "/lib");
 }
 
+sub meta {
+    my $self = shift;
+    CPAN::Meta->load_file($self->path . "/MYMETA.json");
+}
+
+sub requirements {
+    my $self = shift;
+    $self->meta->effective_prereqs->merged_requirements(['runtime'], ['requires']);
+}
+
 1;
